pub fn install()Available on Unix and (GNU or macOS) only.
Install the signal handler for the KILL signals.
When one of the KILL signals is delivered to the process, print a stack trace and then exit.
pub fn install()Install the signal handler for the KILL signals.
When one of the KILL signals is delivered to the process, print a stack trace and then exit.