pub struct UnstableOpts {Show 15 fields
pub ui_testing: bool,
pub track_diagnostics: bool,
pub parse_yul: bool,
pub no_resolve_imports: bool,
pub dump: Option<Dump>,
pub ast_stats: bool,
pub hir_stats: bool,
pub standard_json_stats: bool,
pub span_visitor: bool,
pub print_max_storage_sizes: bool,
pub print_natspec: bool,
pub typeck: bool,
pub mir_print_after_each: bool,
pub codegen: bool,
pub help: (),
/* private fields */
}Expand description
Internal options.
Fields
ui_testing: boolEnables UI testing mode.
track_diagnostics: boolPrints a note for every diagnostic that is emitted with the creation and emission location.
This is enabled by default on debug builds.
parse_yul: boolEnables parsing Yul files for testing.
no_resolve_imports: boolDisables import resolution.
dump: Option<Dump>Print additional information about the compiler’s internal state.
Valid kinds are ast and hir.
ast_stats: boolPrint AST stats.
hir_stats: boolPrint HIR stats.
standard_json_stats: boolPrint Standard JSON input stats.
span_visitor: boolRun the span visitor after parsing.
print_max_storage_sizes: boolPrint contracts’ max storage sizes.
print_natspec: boolPrint resolved NatSpec docs as diagnostics for UI tests.
typeck: boolType check the program. WIP.
mir_print_after_each: boolPrint MIR after every MIR optimization pass during codegen.
codegen: boolEnable the experimental EVM code generator (MIR lowering and backend).
Off by default: MIR and bytecode output is only produced when this is set. Codegen is a work in progress and not yet part of the compiler’s stable, solc-compatible behavior.
help: ()Print help.