Module version

Module version 

Solar version information.

Constants

SEMVER_VERSION
The semver version information.
SHORT_VERSIONversion
The short version information.
SOLC_VERSIONversion
The solc-compatible long version information.
VERSIONversion
The long version information.

Functions

short_versionversion
Returns the short version selected for the current environment.
versionversion
Returns the long version selected for the current environment.