Solar version information.
Constants
- SEMVER_
VERSION - The semver version information.
- SHORT_
VERSION version - The short version information.
- SOLC_
VERSION version - The solc-compatible long version information.
- VERSION
version - The long version information.
Functions
- short_
version version - Returns the short version selected for the current environment.
- version
version - Returns the long version selected for the current environment.